<?xml version="1.0" encoding="utf-8"?>
<xsl:stylesheet version="1.0"
  xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
  xmlns:msxsl="urn:schemas-microsoft-com:xslt"
  xmlns:user="http://cmsconnect.com/usernamespace"
  xmlns:ds="http://tempuri.org/ConnDS.xsd">
   
  <!--
  This transform accepts two parameters used to specify the column you
  want sorted and the direction
  -->
  <xsl:param name="IsSupported" />
  <xsl:param name="IsRegistered" />
  <xsl:param name="IP2CVersion" />
  <xsl:param name="SupportExpiration" />
  
  <xsl:output method="text" />
  <msxsl:script language="C#" implements-prefix="user">
    <![CDATA[

    public string CutIt( string sInp, 
                         int    iMaxLen, 
                         int    iAtSignCheck )
    {
        string  cFILLER1 = "[...]";
        string  strR    = "";
        string  strL    = sInp;
        string  sReturn = sInp;
        int     iLen    = sInp.Length;

        if( iMaxLen > 10 && iLen > iMaxLen ) 
        {
            if( iAtSignCheck == 1 ) 
            { 
                int iPos = sInp.IndexOf( "@" );
                if( iPos > 0 ) {
                    strL = sInp.Substring( 0, iPos-1 );
                    strR = sInp.Substring( iPos );
                }
            }       
            
            int iLenL = iMaxLen - strR.Length - cFILLER1.Length;
            
            if( iLenL > 0 )
                strL = strL.Substring( 0, iLenL ).Trim() + cFILLER1;
            else {
                strL = sInp.Substring( 0, (iMaxLen - cFILLER1.Length ) ) + cFILLER1;
                strR = "";
            }
            
            sReturn = strL + strR;
        }
        
        return( sReturn );
    }


    public string FixedText( string sInp, int iFixedLen )
    {
       string   sfixed = CutIt( sInp, iFixedLen, 0 );
       int      ilen   = sfixed.Length;
       
       if ( ilen < iFixedLen ) {
          int       ipadsize = iFixedLen - ilen;
          string    spad     = new string( ' ', ipadsize );

          sfixed += spad;
       }

       return( sfixed );
       
    } // FixedText
    
    
  ]]>
  </msxsl:script>

  
  <xsl:template match="/">

    <xsl:text>************************** XE-Filter(tm) Notice **************************&#13;&#xA;</xsl:text>
    <xsl:text>Country-Centric IP-based e-Mail Filtering by Computer Mail Services, Inc.&#13;&#xA;</xsl:text>
    <xsl:text>&#13;&#xA;</xsl:text>
    <xsl:text>&#13;&#xA;</xsl:text>
    
    <!--  SUPPORTED Notice -->
    <xsl:if test="$IsSupported='true'">

       <!--  IP2C Version -->
       <xsl:text>Country IP Database date:   </xsl:text><xsl:value-of select="$IP2CVersion" />
       <xsl:text>&#13;&#xA;</xsl:text>
       <xsl:text>Support Expiration date:    </xsl:text><xsl:value-of select="$SupportExpiration" />
       <xsl:text>&#13;&#xA;</xsl:text>
       <xsl:text>&#13;&#xA;</xsl:text>

      <xsl:text>An updated Country IP database was available and as a supported&#13;&#xA;</xsl:text>
      <xsl:text>customer, this update was downloaded and is now online.&#13;&#xA;</xsl:text>
      <xsl:text>&#13;&#xA;</xsl:text>
      <xsl:text>No futher action is required.&#13;&#xA;</xsl:text>
      <xsl:text>XE-Filter's Country database is now up to date.&#13;&#xA;</xsl:text>
      <xsl:text>&#13;&#xA;</xsl:text>
    </xsl:if>


    <!--  UNsupported Notice -->
    <xsl:if test="$IsSupported='false'">

       <xsl:choose>

          <!-- Registered Text -->
          <xsl:when test="$IsRegistered='true'">
             
             <!--  IP2C Version -->
             <xsl:text>Available Country IP Database:   </xsl:text><xsl:value-of select="$IP2CVersion" />
             <xsl:text>&#13;&#xA;</xsl:text>
             <xsl:text>Support Expired on:              </xsl:text><xsl:value-of select="$SupportExpiration" />
             <xsl:text>&#13;&#xA;</xsl:text>
             <xsl:text>&#13;&#xA;</xsl:text>

             <xsl:text>An updated Country IP database is available.  However, you are&#13;&#xA;</xsl:text>
             <xsl:text>no longer a supported customer.  In order to receive the latest&#13;&#xA;</xsl:text>
             <xsl:text>database, you must renew your support.&#13;&#xA;</xsl:text>
             <xsl:text>&#13;&#xA;</xsl:text>
             <xsl:text>To renew your support for XE-Filter, please contact CMS or visit CMS' website:&#13;&#xA;</xsl:text>
             <xsl:text>        http://www.CmsConnect.com&#13;&#xA;</xsl:text>
             <xsl:text>&#13;&#xA;</xsl:text>
          </xsl:when>

          <!-- UnRegistered Text -->
          <xsl:otherwise>
             <xsl:text>An updated Country IP database is available.&#13;&#xA;</xsl:text>
             <xsl:text>However, your registration information cannot be found.&#13;&#xA;</xsl:text>
             <xsl:text>In order to receive the latest database, you must be a supported customer.&#13;&#xA;</xsl:text>
             <xsl:text>&#13;&#xA;</xsl:text>
             <xsl:text>To purchase support for XE-Filter, please contact CMS or visit CMS' website:&#13;&#xA;</xsl:text>
             <xsl:text>        http://www.CmsConnect.com&#13;&#xA;</xsl:text>
          </xsl:otherwise>
       </xsl:choose>

    </xsl:if>
    
  </xsl:template >

</xsl:stylesheet> 
