<?xml version="1.0" encoding="utf-8"?>
<xsl:stylesheet version="1.0"
  xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
  xmlns:msxsl="urn:schemas-microsoft-com:xslt"
  xmlns:user="http://cmsconnect.com/usernamespace"
  xmlns:ds="http://tempuri.org/ConnDS.xsd">
   
  <!--
  This transform accepts two parameters used to specify the column you
  want sorted and the direction
  -->
  <xsl:param name="SortColumn"/>
  <xsl:param name="SortDir"/>
  <xsl:param name="IsEval" />
  <xsl:param name="LastReset" />
  
  <xsl:output method="text" />
  <msxsl:script language="C#" implements-prefix="user">
    <![CDATA[

    public string CutIt( string sInp, 
                         int    iMaxLen, 
                         int    iAtSignCheck )
    {
        string  cFILLER1 = "[...]";
        string  strR    = "";
        string  strL    = sInp;
        string  sReturn = sInp;
        int     iLen    = sInp.Length;

        if( iMaxLen > 10 && iLen > iMaxLen ) 
        {
            if( iAtSignCheck == 1 ) 
            { 
                int iPos = sInp.IndexOf( "@" );
                if( iPos > 0 ) {
                    strL = sInp.Substring( 0, iPos-1 );
                    strR = sInp.Substring( iPos );
                }
            }       
            
            int iLenL = iMaxLen - strR.Length - cFILLER1.Length;
            
            if( iLenL > 0 )
                strL = strL.Substring( 0, iLenL ).Trim() + cFILLER1;
            else {
                strL = sInp.Substring( 0, (iMaxLen - cFILLER1.Length ) ) + cFILLER1;
                strR = "";
            }
            
            sReturn = strL + strR;
        }
        
        return( sReturn );
    }


    public string FixedText( string sInp, int iFixedLen )
    {
       string   sfixed = CutIt( sInp, iFixedLen, 0 );
       int      ilen   = sfixed.Length;
       
       if ( ilen < iFixedLen ) {
          int       ipadsize = iFixedLen - ilen;
          string    spad     = new string( ' ', ipadsize );

          sfixed += spad;
       }

       return( sfixed );
       
    } // FixedText
    
    
  ]]>
  </msxsl:script>

  
  <xsl:template match="/">

    <xsl:text>********************* XE-Filter(tm) Country Summary *********************&#13;&#xA;</xsl:text>
    <xsl:text>Country-Centric IP-based e-Mail Filtering by Computer Mail Services, Inc.&#13;&#xA;</xsl:text>
    <xsl:text>&#13;&#xA;</xsl:text>
    <xsl:text>&#13;&#xA;</xsl:text>
    
    <!--  EVAL Warning -->
    <xsl:if test="$IsEval='true'">
      <xsl:text>The EVALUATION version of XE-Filter is currently running.&#13;&#xA;</xsl:text>
      <xsl:text>This means that mail is never banned.  Instead, XE-Filter monitors what&#13;&#xA;</xsl:text>
      <xsl:text>would have been banned if the full version is running.&#13;&#xA;</xsl:text>
      <xsl:text>&#13;&#xA;</xsl:text>
      <xsl:text>To purchase the full version of XE-Filter, go to http://www.cmsconnect.com/XEFPro/XEFPricing.htm &#13;&#xA;</xsl:text>
      <xsl:text>&#13;&#xA;</xsl:text>
    </xsl:if>

    <!--  Last Reset Time -->
    <xsl:text>Last Reset Time:   </xsl:text><xsl:value-of select="$LastReset" />
    <xsl:text>&#13;&#xA;</xsl:text>
    <xsl:text>&#13;&#xA;</xsl:text>
    
    <!--  Column Header -->
    <xsl:value-of select="user:FixedText('Code', 5)" />
     <xsl:value-of select="user:FixedText('Country Name', 40)" />
     <xsl:value-of select="user:FixedText('Allowed', 10)" />
     <xsl:choose>
        <xsl:when test="$IsEval='true'"><xsl:value-of select="user:FixedText('Would-be-Banned',16)"/></xsl:when>
        <xsl:otherwise><xsl:value-of select="user:FixedText('Banned', 16)"/></xsl:otherwise>
     </xsl:choose> 
    <xsl:text>&#13;&#xA;</xsl:text>
    
    <!--  Column Underline -->
    <xsl:value-of select="user:FixedText('----',5)"/>
    <xsl:value-of select="user:FixedText('------------', 40)"/>
    <xsl:value-of select="user:FixedText('-------', 10)"/>
    <xsl:choose>
      <xsl:when test="$IsEval='true'"><xsl:value-of select="user:FixedText('---------------', 16)"/></xsl:when>
      <xsl:otherwise><xsl:value-of select="user:FixedText('------',16)"/></xsl:otherwise>
    </xsl:choose>
    <xsl:text>&#13;&#xA;</xsl:text>
    
    <!--  Details Section -->
    <xsl:for-each select="/ds:ConnDS/ds:tblConnection">
        <xsl:sort select="./*[local-name()=$SortColumn]" data-type="number" order="{$SortDir}"/>
     
        <xsl:variable name="ccode" select="ds:cs" />    
        <xsl:variable name="cname" select="ds:cl" />    
        <xsl:variable name="allowed" select="format-number(ds:ac, '###,###,###,##0')" />
        <xsl:variable name="denied" select="format-number(ds:dc, '###,###,###,##0')" />
    
        <xsl:value-of select="user:FixedText($ccode, 5)" />
        <xsl:value-of select="user:FixedText($cname, 40)" />
        <xsl:value-of select="user:FixedText($allowed, 10)" />
        <xsl:value-of select="user:FixedText($denied, 16)" />
        <xsl:text>&#13;&#xA;</xsl:text>
     </xsl:for-each>

    <!-- Calculate Totals and Percentages  -->
    <xsl:variable name ="TotalAC" select="sum(/ds:ConnDS/ds:tblConnection/ds:ac)" />
    <xsl:variable name ="TotalDC" select="sum(/ds:ConnDS/ds:tblConnection/ds:dc)" />
    <xsl:variable name ="GrandTotal" select="$TotalAC + $TotalDC" />
    <xsl:variable name ="PctAC" select="format-number(($TotalAC *100) div $GrandTotal, '##.#')" />
    <xsl:variable name ="PctDC" select="format-number(($TotalDC *100) div $GrandTotal, '##.#')" />
                  
    <!-- Output Totals -->
    <xsl:value-of select ="user:FixedText(' ', 5)"/>
    <xsl:value-of select ="user:FixedText('TOTALS', 40)"/>
    <xsl:value-of select ="user:FixedText(format-number($TotalAC,'###,###,###,##0'),10)"/>
    <xsl:value-of select ="user:FixedText(format-number($TotalDC,'###,###,###,##0'),16)"/>
    <xsl:text>&#13;&#xA;</xsl:text>
    
    <!-- Output Percentages -->
    <xsl:value-of select ="user:FixedText(' ', 5)"/>
    <xsl:value-of select ="user:FixedText('Percentage', 40)"/>
    <xsl:value-of select ="user:FixedText(concat($PctAC, '%'),10)"/>
    <xsl:value-of select ="user:FixedText(concat($PctDC, '%'),16)"/>


  </xsl:template >

</xsl:stylesheet> 
